@@ -56,7 +56,7 @@ import unittest
 import pandas as pd
 
 from nose.tools import assert_equal, nottest
-from pandas.util.testing import assert_frame_equal
+from pandas.testing import assert_frame_equal
 
 from pyani import anib, pyani_files
 
